Documentation
¶
Index ¶
Constants ¶
const (
ContextKeyUserInfo = app.ContextKey("user_info")
)
Variables ¶
This section is empty.
Functions ¶
func BuildAuthInterceptor ¶
func BuildAuthInterceptor( publicMethodMap map[string]bool, jwtSecret string, ) grpc.UnaryServerInterceptor
func CheckPermission ¶ added in v0.1.1
CheckPermission checks if a user role has permission to access a method
func NewEnforcer ¶ added in v0.1.1
NewEnforcer creates a new Casbin enforcer with the RBAC model and policy
Types ¶
Click to show internal directories.
Click to hide internal directories.